## PYRSM

Python functions for Customer Analytics at the Rady School of Management (RSM)

## Links

* [Pandas cheat sheet](https://pandas.pydata.org/Pandas_Cheat_Sheet.pdf)
* [Pandas vs R](https://pandas.pydata.org/pandas-docs/stable/getting_started/comparison/comparison_with_r.html) 
* [Pandas vs R](https://cheatsheets.quantecon.org/stats-cheatsheet.html)
* [Pandas vs R](https://gist.github.com/conormm/fd8b1980c28dd21cfaf6975c86c74d07)
* [Split-Appy-Combine in Pandas](https://pandas.pydata.org/pandas-docs/stable/user_guide/groupby.html)
* [Split-Appy-Combine in Pandas](https://www.shanelynn.ie/summarising-aggregation-and-grouping-data-in-python-pandas/)
* ["assign" in Pandas](http://queirozf.com/entries/mutate-for-pandas-dataframes-examples-with-assign)
* [Condition count](https://stackoverflow.com/a/45752640/1974918)
* [`value_counts` in Pandas](https://appdividend.com/2019/01/24/pandas-series-value_counts-tutorial-with-example/)
* Convert column to string or categorical:
    - df['zipcode'] = df.zipcode.astype(str)
    - df['zipcode'] = df.zipcode.astype('category')

## General Python Learning Resources
* Python for everyone (https://www.py4e.com)
* List object attributes: 
    - dir(instance)
    - instance.__dir__()
    - instance.__dict__
    - type
    - dtype

## Python AND R

* [Reticulate](https://rstudio.github.io/reticulate/articles/calling_python.html)

## Statistics
* [Variance Inflation Factor](https://stackoverflow.com/questions/42658379/variance-inflation-factor-in-python)